/*

  IconFamilies.h
  Source:	Macintosh Technical Note #306 by Jim Mensch and David Collins
 
 	Definitions to deal with icon families under System 7 and later
 
  October 6, 1992  isl
  
*/

#pragma once

/*=====================*/
/*===---------------===*/
																						//	Resource types
#define	Large1BitMask			(long)'ICN#'
#define	Large4BitData			(long)'icl4'
#define	Large8BitData			(long)'icl8'
#define	Small1BitMask			(long)'ics#'
#define	Small4BitData			(long)'ics4'
#define	Small8BitData			(long)'ics8'
#define	Mini1BitMask			(long)'sicn'
#define	Mini4BitData			(long)'icm4'
#define	Mini8BitData			(long)'icm8'

/*===---------------===*/
																						//	IconTransformType values
#define	ttNone									0x0000
#define	ttDisabled							0x0001
#define	ttOffline								0x0002
#define	ttOpen									0x0003
#define	ttSelected							0x4000
#define	ttSelectedDisabled			(ttSelected + ttDisabled)
#define	ttSelectedOffline				(ttSelected + ttOffline)
#define	ttSelectedOpen					(ttSelected + ttOpen)

																						//	Transform label values
#define	ttLabel0								0x0000
#define	ttLabel1								0x0100
#define	ttLabel2								0x0200
#define	ttLabel3								0x0300
#define	ttLabel4								0x0400
#define	ttLabel5								0x0500
#define	ttLabel6								0x0600
#define	ttLabel7								0x0700

/*===---------------===*/
																						//	Alignment values
#define	atNone									0x0000
#define	atVerticalCenter				0x0001
#define	atTop										0x0002
#define	atBottom								0x0003
#define	atHorizontalCenter			0x0004
#define	atLeft									0x0008
#define	atRight									0x000C

/*===---------------===*/
																						//	IconSelectorValue masks
#define	svLarge1Bit							0x00000001
#define	svLarge4Bit							0x00000002
#define	svLarge8Bit							0x00000004
#define	svSmall1Bit							0x00000100
#define	svSmall4Bit							0x00000200
#define	svSmall8Bit							0x00000400
#define	svMini1Bit							0x00010000
#define	svMini4Bit							0x00020000
#define	svMini8Bit							0x00040000
#define	svAllLargeData					0x000000ff
#define	svAllSmallData					0x0000ff00
#define	svAllMiniData						0x00ff0000
#define	svAll1BitData						(svLarge1Bit + svSmall1Bit + svMini1Bit)
#define	svAll4BitData						(svLarge4Bit + svSmall4Bit + svMini4Bit)
#define	svAll8BitData						(svLarge8Bit + svSmall8Bit + svMini8Bit)
#define	svAllAvailableData			0xffffffff
	
/*===---------------===*/
																						//	Routines

pascal OSErr PlotIconID(const Rect *theRect, short align, short  transform, short theResID)
	 = {0x303C, 0x0500, 0xABC9};

pascal OSErr NewIconSuite(Handle *theIconSuite) = {0x303C, 0x0207, 0xABC9};

pascal OSErr AddIconToSuite(Handle theIconData,Handle theSuite,ResType theType)= {0x303C, 0x0608, 0xABC9};

pascal OSErr GetIconFromSuite(Handle *theIconData,Handle theSuite,ResType theType)= {0x303C, 0x0609, 0xABC9};

pascal OSErr ForEachIconDo(Handle theSuite,long selector,ProcPtr action,void *yourDataPtr)
	= {0x303C, 0x080A, 0xABC9};

pascal OSErr GetIconSuite(Handle *theIconSuite,short theResID,long selector)= {0x303C, 0x0501, 0xABC9};	

pascal OSErr DisposeIconSuite(Handle theIconSuite,Boolean disposeData)= {0x303C, 0x0302, 0xABC9};

pascal OSErr PlotIconSuite(const Rect *theRect,short align,short transform,Handle theIconSuite)
	= {0x303C, 0x0603, 0xABC9};

pascal OSErr MakeIconCache(Handle *theHandle,ProcPtr makeIcon,void *yourDataPtr)= {0x303C, 0x0604, 0xABC9};

pascal OSErr LoadIconCache(const Rect *theRect,short align,short transform,Handle theIconCache)
	= {0x303C, 0x0606, 0xABC9};

pascal OSErr GetLabel(short labelNumber,RGBColor *labelColor,Str255 labelString)= {0x303c, 0x050B, 0xABC9};

pascal Boolean PtInIconID(Point testPt,Rect *iconRect,short alignment,short iconID)= {0x303c, 0x060D, 0xABC9};

pascal Boolean PtInIconSuite(Point testPt,Rect *iconRect,short alignment,Handle theIconSuite)
	= {0x303c, 0x070E, 0xABC9};

pascal Boolean RectInIconID(Rect *testRect,Rect *iconRect,short alignment,short iconID)
	= {0x303c, 0x0610, 0xABC9};

pascal Boolean RectInIconSuite(Rect *testRect,Rect *iconRect,short alignment,Handle theIconSuite)
	= {0x303c, 0x0711, 0xABC9};

pascal OSErr IconIDToRgn(RgnHandle theRgn,Rect *iconRect,short alignment,short iconID)
	= {0x303c, 0x0613, 0xABC9};

pascal OSErr IconSuiteToRgn(RgnHandle theRgn,Rect *iconRect,short alignment,Handle theIconSuite)
	= {0x303c, 0x0714, 0xABC9};

pascal OSErr SetSuiteLabel(Handle theSuite, short theLabel)= {0x303C, 0x0316, 0xABC9};

pascal short GetSuiteLabel(Handle theSuite)= {0x303C, 0x0217, 0xABC9};	

pascal OSErr GetIconCacheData(Handle theCache, void **theData)= {0x303C, 0x0419, 0xABC9};	

pascal OSErr SetIconCacheData(Handle theCache, void *theData)= {0x303C, 0x041A, 0xABC9};	

pascal OSErr GetIconCacheProc(Handle theCache, ProcPtr *theProc)= {0x303C, 0x041B, 0xABC9};	

pascal OSErr SetIconCacheProc(Handle theCache, ProcPtr theProc)= {0x303C, 0x041C, 0xABC9};

pascal OSErr PlotSICNHandle(const Rect *theRect,short align,short transform,Handle theSICN)
	= {0x303C, 0x061E, 0xABC9};

pascal OSErr PlotCIconHandle(const Rect *theRect,short align,short transform,CIconHandle theCIcon)
	= {0x303C, 0x061F, 0xABC9};

pascal OSErr SetLabel(short labelNumber, const RGBColor *, ConstStr255Param)
	= {0x303C, 0x050C, 0xABC9};
	
	
/*===---------------===*/
/*=====================*/